@@ -2014,17 +2014,36 @@ reeval_node(ATrie) :-
 reeval_node(ATrie) :-
     '$mono_reeval_prepare'(ATrie, Size),
     !,
-    setup_call_cleanup(
-        '$tbl_propagate_start'(Old),
-        reeval_monotonic_node(ATrie, Size),
-        '$tbl_propagate_end'(Old)).
+    reeval_monotonic_node(ATrie, Size).
 reeval_node(ATrie) :-
     \+ is_invalid(ATrie).
 
 reeval_monotonic_node(ATrie, Size) :-
+    setup_call_cleanup(
+        '$tbl_propagate_start'(Old),
+        reeval_monotonic_node(ATrie, Size, Deps),
+        '$tbl_propagate_end'(Old)),
+    (   Deps == []
+    ->  tdebug(reeval, 'Re-evaluation for ~p complete', [ATrie])
+    ;   Deps == false
+    ->  tdebug(reeval, 'Re-evaluation for ~p queued new answers', [ATrie]),
+        reeval_node(ATrie)
+    ;   tdebug(reeval, 'Re-evaluation for ~p: new invalid deps: ~p',
+               [ATrie, Deps]),
+        reeval_nodes(Deps),
+        reeval_node(ATrie)
+    ).
+
+reeval_nodes([]).
+reeval_nodes([H|T]) :-
+    reeval_node(H),
+    reeval_nodes(T).
+
+reeval_monotonic_node(ATrie, Size, Deps) :-
     tdebug(reeval, 'Re-evaluating lazy monotonic ~p', [ATrie]),
     (   '$idg_mono_affects_lazy'(ATrie, _0SrcTrie, Dep, DepRef, Answers),
         length(Answers, Count),
+        '$idg_mono_empty_queue'(DepRef, Count),
         (   Dep = dependency(Head, Cont, Skel)
         ->  (   '$member'(ClauseRef, Answers),
                 '$clause'(Head, _Body, ClauseRef, _Bindings),
@@ -2033,7 +2052,7 @@ reeval_monotonic_node(ATrie, Size) :-
                 '$idg_set_current'(_, ATrie),
                 pdelim(Cont, Skel, ATrie),
                 fail
-            ;   '$idg_mono_empty_queue'(DepRef, Count)
+            ;   true
             )
         ;   Dep = dependency(SrcSkel, true, Cont, Skel)
         ->  (   '$member'(Node, Answers),
@@ -2043,29 +2062,15 @@ reeval_monotonic_node(ATrie, Size) :-
                 '$idg_set_current'(_, ATrie),
                 pdelim(Cont, Skel, ATrie),
                 fail
-            ;   '$idg_mono_empty_queue'(DepRef, Count)
+            ;   true
             )
         ;   tdebug(monotonic, 'Skipped queued ~p, answers ~p',
                    [Dep, Answers])
         ),
         fail
-    ;   '$mono_reeval_done'(ATrie, Size, Deps),
-        (   Deps == []
-        ->  tdebug(reeval, 'Re-evaluation for ~p complete', [ATrie])
-        ;   Deps == false
-        ->  tdebug(reeval, 'Re-evaluation for ~p queued new answers', [ATrie]),
-            reeval_node(ATrie)
-        ;   tdebug(reeval, 'Re-evaluation for ~p: new invalid deps: ~p', [ATrie, Deps]),
-            reeval_nodes(Deps),
-            reeval_node(ATrie)
-        )
+    ;   '$mono_reeval_done'(ATrie, Size, Deps)
     ).
 
-reeval_nodes([]).
-reeval_nodes([H|T]) :-
-    reeval_node(H),
-    reeval_nodes(T).
-
 
 		 /*******************************
 		 *      EXPAND DIRECTIVES	*
