@@ -3,8 +3,9 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  1985-2020, University of Amsterdam
+    Copyright (c)  1985-2021, University of Amsterdam
                               VU University Amsterdam
+                              SWI-Prolog Solutions b.v.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -1136,6 +1137,7 @@ write_bindings(Bindings, ResidueVars, Delays, Det) :-
     '$current_typein_module'(TypeIn),
     translate_bindings(Bindings, Bindings1, ResidueVars, TypeIn:Residuals),
     omit_qualifier(Delays, TypeIn, Delays1),
+    name_vars(Bindings1, Residuals, Delays1),
     write_bindings2(Bindings1, Residuals, Delays1, Det).
 
 write_bindings2([], Residuals, Delays, _) :-
@@ -1158,6 +1160,50 @@ write_bindings2(Bindings, Residuals, Delays, _Det) :-
         print_message(query, query(done))
     ).
 
+name_vars(Bindings, Residuals, Delays) :-
+    current_prolog_flag(toplevel_name_variables, true),
+    !,
+    '$term_multitons'(t(Bindings,Residuals,Delays), Vars),
+    name_vars_(Vars, Bindings, 0),
+    term_variables(t(Bindings,Residuals,Delays), SVars),
+    anon_vars(SVars).
+name_vars(_Bindings, _Residuals, _Delays).
+
+name_vars_([], _, _).
+name_vars_([H|T], Bindings, N) :-
+    name_var(Bindings, Name, N, N1),
+    H = '$VAR'(Name),
+    name_vars_(T, Bindings, N1).
+
+anon_vars([]).
+anon_vars(['$VAR'('_')|T]) :-
+    anon_vars(T).
+
+name_var(Bindings, Name, N0, N) :-
+    between(N0, infinite, N1),
+    I is N1//26,
+    J is 0'A + N1 mod 26,
+    (   I == 0
+    ->  format(atom(Name), '_~c', [J])
+    ;   format(atom(Name), '_~c~d', [J, I])
+    ),
+    (   current_prolog_flag(toplevel_print_anon, false)
+    ->  true
+    ;   \+ is_bound(Bindings, Name)
+    ),
+    !,
+    N is N1+1.
+
+is_bound([Vars=_|T], Name) :-
+    (   in_vars(Vars, Name)
+    ->  true
+    ;   is_bound(T, Name)
+    ).
+
+in_vars(Name, Name) :- !.
+in_vars(Names, Name) :-
+    '$member'(Name, Names).
+
 %!  residual_goals(:NonTerminal)
 %
 %   Directive that registers NonTerminal as a collector for residual
